[![PyPI version](
https://badge.fury.io/py/dvg-qdeviceio.svg)](https://badge.fury.io/py/dvg-qdeviceio)
[![Build Status](https://travis-ci.org/Dennis-van-Gils/python-dvg-qdeviceio.svg?branch=master)](https://travis-ci.org/Dennis-van-Gils/python-dvg-qdeviceio)
[![Coverage Status](https://coveralls.io/repos/github/Dennis-van-Gils/python-dvg-qdeviceio/badge.svg?branch=master)](https://coveralls.io/github/Dennis-van-Gils/python-dvg-qdeviceio?branch=master)
[![Python 3.6](https://img.shields.io/badge/python-3.6-blue.svg)](https://www.python.org/downloads/release/)
[![Python 3.7](https://img.shields.io/badge/python-3.7-blue.svg)](https://www.python.org/downloads/release/)
[![Python 3.8](https://img.shields.io/badge/python-3.8-blue.svg)](https://www.python.org/downloads/release/)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://github.com/Dennis-van-Gils/python-dvg-qdeviceio/blob/master/LICENSE.txt)

# DvG_QDeviceIO
PyQt5 module containing the framework for multithreaded communication and periodical data acquisition for an I/O device.

In alpha stage. Within a month (at July 2020) I expect a proper release.
